@@ -8,8 +8,8 @@ complexity stamped out (well, eventually :).
 
 """
 
-__revision__ = "$Rev: 332 $"
-__date__ = "$Date: 2006-05-20 22:26:35 +0000 (Sat, 20 May 2006) $"
+__revision__ = "$Rev: 422 $"
+__date__ = "$Date: 2006-10-22 07:47:06 -0400 (Sun, 22 Oct 2006) $"
 
 import release
 __version__ = release.version
@@ -22,37 +22,51 @@ __license__ = release.license
 import sys
 import os
 
+assert sys.hexversion >= 0x02030000, "Kid templates need Python 2.3 or later"
+
+
 from kid.util import xml_sniff, QuickTextReader
 from kid.namespace import Namespace
-from kid.pull import ElementStream, Element, SubElement, Fragment, \
-                     XML, document, _coalesce
-from kid.et import ElementTree, Comment, ProcessingInstruction
-from kid.parser import KID_XMLNS
-from kid.serialization import Serializer, XMLSerializer, HTMLSerializer, PlainSerializer, XHTMLSerializer
+from kid.codewriter import KID_XMLNS
+from kid.compiler import KID_EXT
+from kid.et import Element, SubElement, ElementTree, Comment, \
+    ProcessingInstruction, Fragment
+from kid.parser import ElementStream, XML, document, _coalesce
+from kid.filter import transform_filter
+from kid.serialization import Serializer, PlainSerializer, \
+    XMLSerializer, HTMLSerializer, XHTMLSerializer
+from kid.format import Format, output_formats
+import kid.template_util as template_util
 
 assume_encoding = sys.getdefaultencoding()
 
-def enable_import(suffixes=None):
+
+def enable_import(ext=None, path=None):
     """Enable the kid module loader and import hooks.
-    
+
     This function must be called before importing kid templates if templates
     are not pre-compiled.
-    
-    Note that if your application uses ZODB, you will need to import ZODB
-    before calling this function as ZODB's import hooks have some issues if
-    installed after the kid import hooks.
-    
+
     """
     import kid.importer
-    kid.importer.install(suffixes)
+    kid.importer.install(ext, path)
 
-#
-# Turn on import hook if KID_IMPORT is set
-#
-if os.environ.get('KID_IMPORT', None) is not None:
-    enable_import()
 
-def import_template(name):
+def disable_import(path=None):
+    """Disable the kid module loader and import hooks again."""
+    import kid.importer
+    kid.importer.uninstall(path)
+
+
+# Turn on import hooks if KID_IMPORT variables are set
+if os.environ.get('KID_IMPORT'):
+    enable_import(os.environ.get('KID_IMPORT_EXT'))
+if os.environ.get('KID_IMPORT_PATH'):
+    enable_import(os.environ.get('KID_IMPORT_EXT'),
+        os.environ['KID_IMPORT_PATH'])
+
+
+def import_template(name, encoding=None):
     """Import template by name.
 
     This is identical to calling `enable_import` followed by an import
@@ -76,14 +90,18 @@ def import_template(name):
     components = name.split('.')
     for comp in components[1:]:
         mod = getattr(mod, comp)
+    if encoding:
+        mod.encoding = encoding
     return mod
 
-def load_template(file, name='', cache=1, encoding=None, ns={}):
+
+def load_template(file, name='', cache=True, encoding=None, ns={},
+        entity_map=None, exec_module=None):
     """Bypass import machinery and load a template module directly.
 
     This can be used as an alternative to accessing templates using the
     native python import mechanisms.
-    
+
     file
       Can be a filename, a kid template string, or an open file object.
     name
@@ -94,6 +112,14 @@ def load_template(file, name='', cache=1, encoding=None, ns={}):
       no byte-compiled version is found, an attempt is made to dump a
       byte-compiled version after compiling. This argument is ignored if
       file is not a filename.
+    entity_map
+      Entity map to be used when parsing the template.
+    exec_module
+      If you want full control over how the template module is executed,
+      you can provide this callable that will be called with the template
+      module and the code to be executed as parameters, after the code has
+      been compiled and the module has been created.
+
     """
     if isinstance(file, basestring):
         if xml_sniff(file):
@@ -109,40 +135,53 @@ def load_template(file, name='', cache=1, encoding=None, ns={}):
     if filename != '<string>':
         abs_filename = path.find(filename)
         if not abs_filename:
-            raise Exception, "Template not found: %s (in %s)" % (
-                filename, ', '.join(path.paths))
+            raise template_util.TemplateNotFound(
+                "%s (in %s)" % (filename, ', '.join(path.paths)))
         filename = abs_filename
         name = importer.get_template_name(name, filename)
         if sys.modules.has_key(name):
             return sys.modules.get(name)
     import kid.compiler as compiler
     if filename == '<string>':
-        code = compiler.compile(fo, filename, encoding)
+        code = compiler.compile(fo, filename, encoding, entity_map)
     else:
-        template = compiler.KidFile(filename, 0, encoding)
-        code = template.compile(dump_code=cache, dump_source=os.environ.get('KID_OUTPUT_PY'))
-    
-    mod = importer._create_module(code, name, filename, store=cache, ns=ns)
+        template = compiler.KidFile(filename, force=False,
+            encoding=encoding, entity_map=entity_map)
+        code = template.compile(dump_code=cache,
+            dump_source=os.environ.get('KID_OUTPUT_PY'))
+    mod = importer._create_module(code, name, filename,
+        store=cache, ns=ns, exec_module=exec_module)
     return mod
 
-# create some default serializers..
-output_methods = {
-    'xml'          : XMLSerializer(decl=1),
-    'xhtml'        : XHTMLSerializer(decl=0, doctype='xhtml'),
-    'xhtml-strict' : XHTMLSerializer(decl=0, doctype='xhtml-strict'),
-    'html'         : HTMLSerializer(doctype='html'),
-    'html-strict'  : HTMLSerializer(doctype='html-strict'),
-    'plain':         PlainSerializer()}
 
-def Template(file=None, source=None, name=None, **kw):
+# create some default serializers...
+output_methods = {
+    'xml': XMLSerializer(decl=True),
+    'xhtml-strict': XHTMLSerializer(decl=False, doctype='xhtml-strict'),
+    'xhtml': XHTMLSerializer(decl=False, doctype='xhtml'),
+    'xhtml-frameset': XHTMLSerializer(decl=False, doctype='xhtml-frameset'),
+    'html-strict': HTMLSerializer(doctype='html-strict'),
+    'html': HTMLSerializer(doctype='html'),
+    'html-frameset': HTMLSerializer(doctype='html-frameset'),
+    'html-quirks': HTMLSerializer(doctype='html-quirks'),
+    'html-frameset-quirks': HTMLSerializer(doctype='html-frameset-quirks'),
+    'HTML-strict': HTMLSerializer(doctype='html-strict', transpose=True),
+    'HTML': HTMLSerializer(doctype='html', transpose=True),
+    'HTML-frameset': HTMLSerializer(doctype='html-frameset', transpose=True),
+    'HTML-quirks': HTMLSerializer(doctype='html-quirks', transpose=True),
+    'HTML-frameset-quirks': HTMLSerializer(doctype='html-frameset-quirks', transpose=True),
+    'plain': PlainSerializer()}
+
+
+def Template(file=None, source=None, name=None, encoding=None, **kw):
     """Get a Template class quickly given a module name, file, or string.
-    
+
     This is a convenience function for getting a template in a variety of
     ways. One and only one of the arguments name or file must be specified.
-    
+
     file:string
       The template module is loaded by calling
-      ``load_template(file, name='', cache=1)``
+      ``load_template(file, name='', cache=True)``
     name:string
       The kid import hook is enabled and the template module is located
       using the normal Python import mechanisms.
@@ -154,17 +193,18 @@ def Template(file=None, source=None, name=None, **kw):
     function.
     """
     if name:
-        mod = import_template(name)
+        mod = import_template(name, encoding=encoding)
     elif file is not None:
-        mod = load_template(file)
+        mod = load_template(file, name=name, encoding=encoding)
     elif source is not None:
-        mod = load_template(QuickTextReader(source), hex(id(source)))
+        mod = load_template(QuickTextReader(source),
+            name=name or hex(id(source)), encoding=encoding)
     else:
-        raise Exception("Must specify one of name, file, or source.")
+        raise template_util.TemplateError(
+            "Must specify one of name, file, or source.")
     mod.Template.module = mod
     return mod.Template(**kw)
 
-from kid.filter import transform_filter
 
 class BaseTemplate(object):
 
@@ -173,36 +213,42 @@ class BaseTemplate(object):
     All kid template modules expose a class named ``Template`` that
     extends from this class making the methods defined here available on
     all Template subclasses.
-    
+
     This class should not be instantiated directly.
     """
-    
+
     # the serializer to use when writing output
     serializer = output_methods['xml']
     _filters = [transform_filter]
-    
+
     def __init__(self, *args, **kw):
         """
         Initialize a template with instance attributes specified by
         keyword arguments.
-           
+
         Keyword arguments are available to the template using self.var
         notation.
         """
+        for k in kw:
+            # check that reserved keywords such as 'content' are not used
+            if hasattr(BaseTemplate, k):
+                raise template_util.TemplateAttrsError(
+                    "Keyword argument %r is a reserved name." % k)
         self.__dict__.update(kw)
         self._layout_classes = []
-        
-    def write(self, file, encoding=None, fragment=0, output=None):
+
+    def write(self, file, encoding=None,
+            fragment=False, output=None, format=None):
         """
         Execute template and write output to file.
-        
+
         file:file
           A filename or a file like object (must support write()).
         encoding:string
           The output encoding. Default: utf-8.
         fragment:bool
           Controls whether prologue information (such as <?xml?>
-          declaration and DOCTYPE should be written). Set to 1
+          declaration and DOCTYPE should be written). Set to True
           when generating fragments meant to be inserted into
           existing XML documents.
         output:string,`Serializer`
@@ -210,44 +256,46 @@ class BaseTemplate(object):
           'xhtml') or a Serializer object.
         """
         serializer = self._get_serializer(output)
-        return serializer.write(self, file, encoding, fragment)
-    
-    def serialize(self, encoding=None, fragment=0, output=None):
+        return serializer.write(self, file, encoding, fragment, format)
+
+    def serialize(self, encoding=None,
+            fragment=False, output=None, format=None):
         """
         Execute a template and return a single string.
-        
+
         encoding
           The output encoding. Default: utf-8.
         fragment
           Controls whether prologue information (such as <?xml?>
-          declaration and DOCTYPE should be written). Set to 1
+          declaration and DOCTYPE should be written). Set to True
           when generating fragments meant to be inserted into
           existing XML documents.
         output
           A string specifying an output method ('xml', 'html',
           'xhtml') or a Serializer object.
-        
+
         This is a convienence method, roughly equivalent to::
-        
+
           ''.join([x for x in obj.generate(encoding, fragment, output)]
-        
+
         """
         serializer = self._get_serializer(output)
-        return serializer.serialize(self, encoding, fragment)
+        return serializer.serialize(self, encoding, fragment, format)
 
-    def generate(self, encoding=None, fragment=0, output=None):
+    def generate(self, encoding=None,
+            fragment=False, output=None, format=None):
         """
         Execute template and generate serialized output incrementally.
-        
+
         This method returns an iterator that yields an encoded string
         for each iteration. The iteration ends when the template is done
         executing.
-        
+
         encoding
           The output encoding. Default: utf-8.
         fragment
           Controls whether prologue information (such as <?xml?>
-          declaration and DOCTYPE should be written). Set to 1
+          declaration and DOCTYPE should be written). Set to True
           when generating fragments meant to be inserted into
           existing XML documents.
         output
@@ -255,30 +303,30 @@ class BaseTemplate(object):
           'xhtml') or a Serializer object.
         """
         serializer = self._get_serializer(output)
-        return serializer.generate(self, encoding, fragment)
-    
+        return serializer.generate(self, encoding, fragment, format)
+
     def __iter__(self):
         return iter(self.transform())
-    
+
     def __str__(self):
         return self.serialize()
-    
+
     def __unicode__(self):
         return unicode(self.serialize(encoding='utf-16'), 'utf-16')
 
     def initialize(self):
         pass
-    
+
     def pull(self):
         """Returns an iterator over the items in this template."""
         # create stream and apply filters
         self.initialize()
         stream = ElementStream(_coalesce(self.content(), self._get_assume_encoding()))
         return stream
-    
+
     def _pull(self):
         """Generate events for this template.
-        
+
         Compiled templates implement this method.
         """
         return []
@@ -293,13 +341,13 @@ class BaseTemplate(object):
                 visited.insert(0, c)
                 return c.__dict__['layout'](self)
         return self._pull()
-    
+
     def transform(self, stream=None, filters=[]):
         """
         Execute the template and apply any match transformations.
-        
+
         If stream is specified, it must be one of the following:
-        
+
         Element
           An ElementTree Element.
         ElementStream
@@ -316,7 +364,7 @@ class BaseTemplate(object):
             stream = self.pull()
         elif isinstance(stream, basestring):
             if xml_sniff(stream):
-                stream = XML(stream, fragment=0)
+                stream = XML(stream, fragment=False)
             else:
                 stream = document(stream)
         elif hasattr(stream, 'tag'):
@@ -326,7 +374,7 @@ class BaseTemplate(object):
         for f in filters + self._filters:
             stream = f(stream, self)
         return stream
-            
+
     def _get_match_templates(self):
         # XXX: use inspect instead of accessing __mro__ directly
         try:
@@ -353,44 +401,70 @@ class BaseTemplate(object):
 
     def _get_assume_encoding(self):
         global assume_encoding
-        
+
         if hasattr(self, "assume_encoding"):
             return self.assume_encoding
         else:
             return assume_encoding
-    
+
     def defined(self, name):
         return hasattr(self, name)
-    
+
     def value_of(self, name, default=None):
         return getattr(self, name, default)
-            
+
+
 class TemplatePath(object):
+    """Finding templates on a list of paths."""
+
     def __init__(self, paths=None):
+        """Initialize with path list."""
         if isinstance(paths, basestring):
-            paths = [paths]
+            paths = paths.split(os.pathsep)
         elif paths is None:
             paths = []
-        paths += [os.getcwd(), '/']
-        self.paths = [self._cleanse_path(p) for p in paths]
+        paths.append(os.getcwd())
+        self.paths = []
+        for path in paths:
+            self.append(path)
 
     def _cleanse_path(self, path):
-        from os.path import normpath, expanduser, abspath
-        return abspath(normpath(expanduser(path)))
-    
+        """Normalize path."""
+        return os.path.abspath(os.path.normpath(os.path.expanduser(path)))
+
     def insert(self, path, pos=0):
-        self.paths.insert(pos, self._cleanse_path(path))
-    
+        """Insert path to list if not already there."""
+        path = self._cleanse_path(path)
+        if path not in self.paths:
+            self.paths.insert(pos, path)
+
     def append(self, path):
-        self.paths.append(self._cleanse_path(path))
-    
-    def find(self, path, rel="/"):
-        from os.path import normpath, join, exists, dirname
-        path = normpath(path)
-        for p in self.paths + [dirname(rel)]:
-            p = join(p, path)
-            if exists(p):
+        """Append path to list if not already there."""
+        path = self._cleanse_path(path)
+        if path not in self.paths:
+            self.paths.append(path)
+
+    def remove(self, path):
+        """Remove path from list."""
+        path = self._cleanse_path(path)
+        self.paths = [p for p in self.paths if p != path]
+
+    def find(self, path, rel=None):
+        """Find file relative to path list and rel."""
+        path = os.path.normpath(path)
+        if rel:
+            rel = [os.path.dirname(rel)]
+        else:
+            rel = []
+        for p in self.paths + rel:
+            p = os.path.join(p, path)
+            if os.path.exists(p):
                 return p
+            if not p.endswith(KID_EXT):
+                p += KID_EXT
+                if os.path.exists(p):
+                    return p
+
 
 path = TemplatePath()
 
@@ -400,5 +474,6 @@ properties = kid.properties
 __all__ = ['KID_XMLNS', 'BaseTemplate', 'Template',
            'enable_import', 'import_template', 'load_template',
            'Element', 'SubElement', 'XML', 'document', 'Namespace',
-           'Serializer', 'XMLSerializer', 'HTMLSerializer', 'XHTMLSerializer', 'output_methods',
-           'filter', 'namespace', 'serialization', 'util', 'properties']
+           'Serializer', 'XMLSerializer', 'HTMLSerializer', 'XHTMLSerializer',
+           'output_methods', 'Format', 'output_formats',
+           'filter', 'format', 'namespace', 'serialization', 'util', 'properties']
