@@ -1,5 +1,5 @@
 
-namespaces = {} 
+namespaces = {}
 
 class Namespace(object):
     def __init__(self, uri, prefix=None):
@@ -7,22 +7,22 @@ class Namespace(object):
         self.prefix = prefix
         if prefix:
             namespaces[uri] = prefix
-            
+
     def qname(self, name):
         if self.prefix:
-            return self.prefix + ':' + name
+            return '%s:%s' % (self.prefix, name)
         else:
             return name
-        
+
     def clarkname(self, name):
         if self.uri:
             return '{%s}%s' % (self.uri, name)
         else:
             return name
-    
+
     __getattr__ = clarkname
     __getitem__ = clarkname
-    
+
     def __str__(self):
         return self.uri
 
@@ -39,7 +39,7 @@ class Namespace(object):
             return self.uri == other.uri
         else:
             return False
-    
+
 xml = Namespace('http://www.w3.org/XML/1998/namespace', 'xml')
 xhtml = Namespace('http://www.w3.org/1999/xhtml', 'html')
 atom = Namespace('http://purl.org/atom/ns#', 'atom')
