@@ -1,9 +1,4 @@
-version = "0.9.3"
-author = "Ryan Tomayko"
-email = "rtomayko@gmail.com"
-copyright = "Copyright 2004-2006, Ryan Tomayko, David Stanek, Christoph Zwerschke, Daniel Miller"
-license = "MIT" # http://www.opensource.org/licenses/mit-license.php
-long_description = """Pythonic, XML Templating
+"""Pythonic, XML Templating
 
 Kid is a simple, Python-based template language for generating and
 transforming XML vocabularies. Kid was spawned as a result of a kinky love
@@ -12,3 +7,14 @@ of these languages live on in Kid with much of the limitations and
 complexity stamped out (well, eventually :).
 
 """
+
+__revision__ = "$Rev: 436 $"
+__date__ = "$Date: 2006-11-26 04:56:03 -0500 (Sun, 26 Nov 2006) $"
+
+version = "0.9.4"
+author = "Ryan Tomayko"
+email = "rtomayko@gmail.com"
+copyright = "Copyright 2004-2006, Ryan Tomayko, " \
+    "David Stanek, Christoph Zwerschke, Daniel Miller"
+license = "MIT" # http://www.opensource.org/licenses/mit-license.php
+long_description = '\n'.join(__doc__.splitlines()[1:]).strip()
