@@ -1,4 +1,4 @@
-#!/usr/bin/python
+#!/usr/bin/env python
 
 # This module provides the "kid" command
 
@@ -31,8 +31,8 @@ args:
   key=value or other arguments passed to the template.
 """
 
-__revision__ = "$Rev: 139 $"
-__date__ = "$Date: 2005-03-14 19:28:22 -0500 (Mon, 14 Mar 2005) $"
+__revision__ = "$Rev: 421 $"
+__date__ = "$Date: 2006-10-22 07:02:46 -0400 (Sun, 22 Oct 2006) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -41,6 +41,11 @@ import sys
 from os.path import dirname, abspath
 from getopt import getopt, GetoptError as gerror
 
+try:
+    from os import EX_OK, EX_DATAERR, EX_USAGE
+except:
+    EX_OK, EX_DATAERR, EX_USAGE = 0, 1, 2
+
 import kid
 
 def main():
@@ -51,7 +56,7 @@ def main():
     except gerror, e:
         sys.stderr.write(str(e) + '\n')
         sys.stdout.write(__doc__)
-        sys.exit(2)
+        sys.exit(EX_USAGE)
     enc = 'utf-8'
     outfile = server = None
     for o, a in opts:
@@ -63,11 +68,11 @@ def main():
             server = a
         elif o in ('-h', '--help'):
             sys.stdout.write(__doc__)
-            sys.exit(0)
+            sys.exit(EX_OK)
         elif o in ('-V', '--version'):
             from kid import __version__
             sys.stdout.write('Kid %s\n' % __version__)
-            sys.exit(0)
+            sys.exit(EX_OK)
     if server is None:
         if args:
             # get template file
@@ -93,15 +98,15 @@ def main():
             __name__ = '__kid_main__'
             del sys.modules['__main__']
             # load kid template as __main__ module
-            module = kid.load_template(f, name='__main__', cache=0)
+            module = kid.load_template(f, name='__main__', cache=False)
             # execute the template and write output
             if not outfile:
-                    outfile = sys.stdout
+                outfile = sys.stdout
             module.write(outfile, encoding=enc, **kw)
         else:
             sys.stderr.write('kid: No template file specified.\n')
             sys.stderr.write("     Try 'kid --help' for usage information.\n")
-            sys.exit(2)
+            sys.exit(EX_USAGE)
     else:
         if len(args) < 2:
             if outfile:
@@ -129,7 +134,7 @@ def main():
         else:
             sys.stderr.write('kid: Server does not need additional arguments.\n')
             sys.stderr.write("     Try 'kid --help' for usage information.\n")
-            sys.exit(2)
+            sys.exit(EX_USAGE)
 
 if __name__ == '__main__':
     main()
