@@ -1,17 +1,17 @@
 """Kid test package."""
 
-__revision__ = "$Rev: 59 $"
-__date__ = "$Date: 2005-02-16 15:43:38 -0500 (Wed, 16 Feb 2005) $"
+__revision__ = "$Rev: 421 $"
+__date__ = "$Date: 2006-10-22 07:02:46 -0400 (Sun, 22 Oct 2006) $"
 __author__ = "Ryan Tomayko (rtomayko@gmail.com)"
 __copyright__ = "Copyright 2004-2005, Ryan Tomayko"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
 
-
+import sys
 import os
 import glob
-from os.path import dirname, basename, join, abspath
+from os.path import abspath, basename, dirname, join as joinpath
 
-_mydir = abspath(join(dirname(__file__))) + '/../../'
+_mydir = abspath(joinpath(dirname(__file__))) + '/../../'
 template_dir = _mydir + 'test'
 output_dir = template_dir
 template_package = 'test.'
@@ -22,15 +22,16 @@ test_modules = [basename(f)[:-3] for f in
 additional_tests = 0
 basic_tests = 0
 
-def run_tests():
-    from kid.test.util import run_tests
+def run_suite(args):
+    stop_first = '-x' in args
+    from kid.test.util import run_suite
     tests = ['kid.test.%s' % m for m in test_modules]
-    run_tests(tests)
+    run_suite(tests, stop_first)
 
 from kid.test.util import dot
 
-__all__ = ['dot', 'run_tests', 'template_package', 'output_dir',
-           'template_dir']
+__all__ = ['dot', 'run_suite',
+    'template_package', 'output_dir', 'template_dir']
 
 if __name__ == '__main__':
-    run_tests()
+    run_suite(sys.argv[1:])
