@@ -1,7 +1,7 @@
 """Kid properties tests."""
 
-__revision__ = "$Rev: $"
-__date__ = "$Date: $"
+__revision__ = "$Rev: 421 $"
+__date__ = "$Date: 2006-10-22 07:02:46 -0400 (Sun, 22 Oct 2006) $"
 __author__ = "David Stanek <dstanek@dstanek.com>"
 __copyright__ = "Copyright 2006, David Stanek"
 __license__ = "MIT <http://www.opensource.org/licenses/mit-license.php>"
@@ -21,7 +21,7 @@ def test_api_existing_property():
     property = 'unittest:property'
     expected = 'it worked'
     assert prop.set(property, expected) == expected
-    assert prop.get(property, "it didn't worked") == expected
+    assert prop.get(property, "it didn't work") == expected
     assert prop.isset(property)
 
 def test_api_remove_property():
